@@ -14,9 +14,11 @@ class Client:
         lb_endpoint                 :   Optinoal (bool) - Labelbox GraphQL endpoint
         lb_enable_experimental      :   Optional (bool) - If `True` enables experimental Labelbox SDK features
         lb_app_url                  :   Optional (str) - Labelbox web app URL
+        
     Attributes:
         lb_client                   :   labelbox.Client object
         bq_client                   :   bigquery.Client object
+        
     Key Functions:
         create_data_rows_from_table :   Creates Labelbox data rows (and metadata) given a BigQuery table
         create_table_from_dataset   :   Creates a BigQuery table given a Labelbox dataset
@@ -33,7 +35,7 @@ class Client:
         lb_app_url="https://app.labelbox.com"):  
 
         self.lb_client = labelboxClient(lb_api_key, endpoint=lb_endpoint, enable_experimental=lb_enable_experimental, app_url=lb_app_url)
-        bq_creds = service_account.Credentials.from_service_account_file(google_key)
+        bq_creds = service_account.Credentials.from_service_account_file(google_key) if google_key else None
         self.bq_client = bigquery.Client(project=google_project_name, credentials=bq_creds)
     
     def _sync_metadata_fields(self, bq_table_id, metadata_index={}):
@@ -125,6 +127,7 @@ class Client:
             Returns:
                 True if global keys are available, False if not
             """
+            query_keys = [str(x) for x in global_keys]
             # Create a query job to get data row IDs given global keys
             query_str_1 = """query get_datarow_with_global_key($global_keys:[ID!]!){dataRowsForGlobalKeys(where:{ids:$global_keys}){jobId}}"""
             query_job_id = client.execute(query_str_1, {"global_keys":global_keys})['dataRowsForGlobalKeys']['jobId']
@@ -132,7 +135,7 @@ class Client:
             query_str_2 = """query get_job_result($job_id:ID!){dataRowsForGlobalKeysResult(jobId:{id:$job_id}){data{
                             accessDeniedGlobalKeys\ndeletedDataRowGlobalKeys\nfetchedDataRows{id}\nnotFoundGlobalKeys}jobStatus}}"""
             res = client.execute(query_str_2, {"job_id":query_job_id})['dataRowsForGlobalKeysResult']['data']
-            return res    
+            return res
         global_keys_list = list(global_key_to_upload_dict.keys())
         payload = __check_global_keys(client, global_keys_list)
         loop_counter = 0
